# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 8
%define qtsubminor 1
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtlocation-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtlocation   %mklibname qt%{qtmajor}location %{qtmajor}
%define libqtlocation_d %mklibname qt%{qtmajor}location -d

Name:           qtlocation6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Location component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  qtbase6-qtpaths
BuildRequires:  qttools6

BuildRequires:  cmake(Qt6Core) >= %{version}
BuildRequires:  cmake(Qt6QuickShapesPrivate) >= %{version}
BuildRequires:  cmake(Qt6Gui) >= %{version}
BuildRequires:  cmake(Qt6Network) >= %{version}
BuildRequires:  cmake(Qt6Positioning) >= %{version}
BuildRequires:  cmake(Qt6PositioningQuick) >= %{version}
BuildRequires:  cmake(Qt6Qml) >= %{version}
BuildRequires:  cmake(Qt6Quick) >= %{version}
BuildRequires:  cmake(Qt6QuickTest) >= %{version}
BuildRequires:  cmake(Qt6ShaderTools) >= %{version}
BuildRequires:  cmake(Qt6Test)

Provides:       qt%{qtmajor}-qtlocation = %{version}-%{release}

%description
Qt%{qtmajor} Location component.

The Qt Location API helps creating mapping solutions using
the data available from some of the popular location services.

%files
%license LICENSES/*
%{_qt6_qmldir}/QtLocation/
%{_qt6_plugindir}/geoservices/
%{_qt6_archdatadir}/sbom/qtlocation-%{qtversion}.spdx

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtLocation%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtLocation%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt6_docdir}/qtlocation.qch
%{_qt6_docdir}/qtlocation/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtlocation}
Summary:        Qt%{qtmajor} Location Component Library
Group:          System/Libraries

%description -n %{libqtlocation}
Qt%{qtmajor} Location Component Library.

%files -n %{libqtlocation}
%license LICENSES/*
%{_qt6_libdir}/libQt6Location.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtlocation_d}
Summary:        Devel files needed to build apps based on QtLocation
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}
Requires:       %{libqtlocation} = %{version}
Provides:       libqtlocation6-devel = %{version}
Provides:       libqt6location-devel = %{version}
Provides:       qtlocation6-devel = %{version}
Provides:       qt6location-devel = %{version}

Provides:       libqtlocation6-private-devel = %{version}
Provides:       libqt6location-private-devel = %{version}
Provides:       qtlocation6-private-devel = %{version}
Provides:       qt6location-private-devel = %{version}

%description -n %{libqtlocation_d}
Devel files needed to build apps based on Qt Location.

%files -n %{libqtlocation_d}
%{_qt6_libdir}/libQt6Location.prl
%{_qt6_libdir}/libQt6Location.so
%{_qt6_libdir}/pkgconfig/Qt6Location.pc
%{_qt6_libdir}/cmake/Qt6Location/
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtLocationTestsConfig.cmake
%{_qt6_includedir}/QtLocation/
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_location.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_location_private.pri
%{_qt6_libdir}/qt6/metatypes/qt6location_relwithdebinfo_metatypes.json
%{_qt6_libdir}/qt6/modules/Location*.json
%if %{with examples}
%{_qt6_examplesdir}/location/
%endif

#------------------------------------------------------------------------------

%prep
%setup -q -n qtlocation-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif


%changelog
* Wed Dec 18 2024 daviddavid <daviddavid> 6.8.1-1.mga10
+ Revision: 2126004
- New version 6.8.1

* Sat Oct 05 2024 daviddavid <daviddavid> 6.7.3-1.mga10
+ Revision: 2103609
- New version 6.7.3
- enable docs building

* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083106
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072547
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Thu May 23 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2066226
- New version 6.7.1

* Thu Feb 15 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2041632
- New version 6.6.2

* Thu Oct 19 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 1999036
- New version 6.6.0
- add missing provides on qt6-qtlocation

* Sat Sep 23 2023 daviddavid <daviddavid> 6.5.2-1.mga10
+ Revision: 1989781
- New version 6.5.2
+ papoteur <papoteur>
- imported package qtlocation6

